Imports System.EnterpriseServices

'turn on security for the application and check down to component level
<Assembly: ApplicationAccessControl(Value:=True, AccessChecksLevel:=AccessChecksLevelOption.ApplicationComponent)> 

'turn on security for this class and create a Managers role
'but dont assign the Everyone group to it
<ComponentAccessControl(True), _
SecurityRole("Managers", False)> _
Public Class SecureClass
    Inherits ServicedComponent

    Public Sub New()
    End Sub

    'this method will only be accessible by Managers due to the class setting
    Public Function ManagersOnly() As String
        Return "ok"
    End Function
End Class

'to secure individual methods, we must use an interface
Public Interface ISecurity
    Function ManagersOnly() As String
    Function Everybody() As String
End Interface

'we must tell the system we want to secure individual methods and
'turn on access control
<SecureMethod(), _
ComponentAccessControl(True)> _
Public Class UnSecureClass
    Inherits ServicedComponent
    Implements ISecurity

    Public Sub New()

    End Sub

    'this method can only be called by Managers
    'dont add the Everyone group to the role
    <SecurityRole("Managers", False)> _
    Public Function ManagersOnly() As String Implements ISecurity.ManagersOnly
        'alternatively, do a manual check
        If (ContextUtil.IsSecurityEnabled) Then
            If (ContextUtil.IsCallerInRole("General")) Then
                Return "You are in the General role"
            Else
                Return "You are not in the General role"
            End If
        End If
        Return "security not enabled"
    End Function

    'this method can be called by the General role
    'and add the Everyone group to the role
    <SecurityRole("General", True)> _
    Public Function Everybody() As String Implements ISecurity.Everybody
        Return SecurityCallContext.CurrentCall.OriginalCaller.AccountName
    End Function
End Class
